Virgo
=====

The code is adapted from
`this notebook <https://github.com/interTwin-eu/DT-Virgo-notebooks/blob/main/WP_4_4/interTwin_wp_4.4_synthetic_data.ipynb>`_
available on the Virgo use case's `repository <https://github.com/interTwin-eu/DT-Virgo-notebooks>`_.

To know more on the interTwin Virgo Noise detector use case and its DT, please visit the published deliverables,
`D4.2 <https://zenodo.org/records/10417138>`_, 
`D7.2 <https://zenodo.org/records/10417161>`_ and `D7.4 <https://zenodo.org/records/10224277>`_.

You can find the relevant code in the
`use case's folder on Github <https://github.com/interTwin-eu/itwinai/tree/main/use-cases/virgo>`_,
or by consulting the use case's README: 


.. include:: ../../use-cases/virgo/README.md
   :parser: myst_parser.sphinx_
   :start-line: 6

